@@ -1,6 +1,12 @@
+from __future__ import annotations
+
+from selenium.webdriver import ActionChains as SeleniumActionChains
 from selenium.webdriver.common.by import By
 
-tags = ['h1', 'h2', 'h3', 'h4', 'h5', 'head', 'body', 'input', 'section', 'button', 'a', 'link', 'header']
+from dyatel.mixins.internal_utils import all_tags, get_child_elements
+
+
+selenium_locator_types = get_child_elements(By, str)
 
 
 def get_locator_type(locator: str):
@@ -9,17 +15,23 @@ def get_locator_type(locator: str):
 
     :param locator: regular locator
     :return:
+      By.ID if locator contain ":id" - com.android locator
       By.TAG_NAME if locator contain tag name
       By.XPATH if locator contain slashes and brackets
       By.CSS_SELECTOR if locator contain brackets and no slash
       By.CSS_SELECTOR if locator contain dot and no brackets
       By.ID if there is no any match
     """
+    if locator in selenium_locator_types:
+        raise Exception('Locator type given instead of locator')
+
     brackets = '[' in locator and ']' in locator
     is_only_tags = True
 
-    if locator in tags:
+    if locator in all_tags:
         return By.TAG_NAME
+    elif ':id' in locator:  # Mobile com.android selector
+        return By.ID
     elif '/' in locator:
         return By.XPATH
     elif '/' not in locator and brackets:
@@ -28,7 +40,7 @@ def get_locator_type(locator: str):
         return By.CSS_SELECTOR
 
     for tag in locator.split(' '):
-        is_only_tags = is_only_tags and tag in tags
+        is_only_tags = is_only_tags and tag in all_tags
 
     if is_only_tags:
         return By.TAG_NAME
@@ -57,3 +69,19 @@ def get_legacy_selector(locator, locator_type):
         locator_type = By.CSS_SELECTOR
         locator = f'[name="{locator}"]'
     return locator, locator_type
+
+
+class ActionChains(SeleniumActionChains):
+
+    def move_to_location(self, x: int, y: int) -> ActionChains:
+        """
+        Moving the mouse to specified location
+
+        :param x: x coordinate
+        :param y: y coordinate
+        :return: self
+        """
+        self.w3c_actions.pointer_action.move_to_location(x, y)
+        self.w3c_actions.key_action.pause()
+
+        return self
